pub struct OperationRecord<H: HostTypes> {
pub arity: u64,
pub has_geometric_character: GeometricCharacter,
pub inverse_handle: OperationHandle<H>,
pub composed_of: &'static H::HostString,
pub is_ring_op: bool,
/* private fields */
}Expand description
Phase 8 (orphan-closure) — typed record for Operation<H>.
Carries a field per functional accessor of the trait. Object
fields hold {Range}Handle<H>; iterate via the Resolved wrapper
chain-resolver methods.
Fields
arity: u64has_geometric_character: GeometricCharacterinverse_handle: OperationHandle<H>composed_of: &'static H::HostStringis_ring_op: boolTrait Implementations
Sourceimpl<H: Clone + HostTypes> Clone for OperationRecord<H>where
H::HostString: Clone,
impl<H: Clone + HostTypes> Clone for OperationRecord<H>where
H::HostString: Clone,
Sourcefn clone(&self) -> OperationRecord<H>
fn clone(&self) -> OperationRecord<H>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<H: Debug + HostTypes> Debug for OperationRecord<H>where
H::HostString: Debug,
impl<H: Debug + HostTypes> Debug for OperationRecord<H>where
H::HostString: Debug,
Sourceimpl<H: Hash + HostTypes> Hash for OperationRecord<H>where
H::HostString: Hash,
impl<H: Hash + HostTypes> Hash for OperationRecord<H>where
H::HostString: Hash,
Sourceimpl<H: PartialEq + HostTypes> PartialEq for OperationRecord<H>where
H::HostString: PartialEq,
impl<H: PartialEq + HostTypes> PartialEq for OperationRecord<H>where
H::HostString: PartialEq,
Sourcefn eq(&self, other: &OperationRecord<H>) -> bool
fn eq(&self, other: &OperationRecord<H>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<H: Eq + HostTypes> Eq for OperationRecord<H>where
H::HostString: Eq,
impl<H: HostTypes> StructuralPartialEq for OperationRecord<H>