pub struct ApplicationExpressionRecord<H: HostTypes> {
pub expression_operator_handle: OperationHandle<H>,
/* private fields */
}Expand description
Phase 8 (orphan-closure) — typed record for ApplicationExpression<H>.
Carries a field per functional accessor of the trait. Object
fields hold {Range}Handle<H>; iterate via the Resolved wrapper
chain-resolver methods.
Fields
expression_operator_handle: OperationHandle<H>Trait Implementations
Sourceimpl<H: Clone + HostTypes> Clone for ApplicationExpressionRecord<H>
impl<H: Clone + HostTypes> Clone for ApplicationExpressionRecord<H>
Sourcefn clone(&self) -> ApplicationExpressionRecord<H>
fn clone(&self) -> ApplicationExpressionRecord<H>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<H: PartialEq + HostTypes> PartialEq for ApplicationExpressionRecord<H>
impl<H: PartialEq + HostTypes> PartialEq for ApplicationExpressionRecord<H>
Sourcefn eq(&self, other: &ApplicationExpressionRecord<H>) -> bool
fn eq(&self, other: &ApplicationExpressionRecord<H>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<H: Eq + HostTypes> Eq for ApplicationExpressionRecord<H>
impl<H: HostTypes> StructuralPartialEq for ApplicationExpressionRecord<H>