pub struct InfixExpressionRecord<H: HostTypes> {
pub left_operand_handle: TermExpressionHandle<H>,
pub right_operand_handle: TermExpressionHandle<H>,
pub infix_operator: &'static H::HostString,
/* private fields */
}Expand description
Phase 8 (orphan-closure) — typed record for InfixExpression<H>.
Carries a field per functional accessor of the trait. Object
fields hold {Range}Handle<H>; iterate via the Resolved wrapper
chain-resolver methods.
Fields
left_operand_handle: TermExpressionHandle<H>right_operand_handle: TermExpressionHandle<H>infix_operator: &'static H::HostStringTrait Implementations
Sourceimpl<H: Clone + HostTypes> Clone for InfixExpressionRecord<H>where
H::HostString: Clone,
impl<H: Clone + HostTypes> Clone for InfixExpressionRecord<H>where
H::HostString: Clone,
Sourcefn clone(&self) -> InfixExpressionRecord<H>
fn clone(&self) -> InfixExpressionRecord<H>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<H: Debug + HostTypes> Debug for InfixExpressionRecord<H>where
H::HostString: Debug,
impl<H: Debug + HostTypes> Debug for InfixExpressionRecord<H>where
H::HostString: Debug,
Sourceimpl<H: Hash + HostTypes> Hash for InfixExpressionRecord<H>where
H::HostString: Hash,
impl<H: Hash + HostTypes> Hash for InfixExpressionRecord<H>where
H::HostString: Hash,
Sourceimpl<H: PartialEq + HostTypes> PartialEq for InfixExpressionRecord<H>where
H::HostString: PartialEq,
impl<H: PartialEq + HostTypes> PartialEq for InfixExpressionRecord<H>where
H::HostString: PartialEq,
Sourcefn eq(&self, other: &InfixExpressionRecord<H>) -> bool
fn eq(&self, other: &InfixExpressionRecord<H>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<H: Eq + HostTypes> Eq for InfixExpressionRecord<H>where
H::HostString: Eq,
impl<H: HostTypes> StructuralPartialEq for InfixExpressionRecord<H>